@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -71,7 +71,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 19 "../../../plugins/am-project/am-parser.y" /* yacc.c:339  */
+#line 19 "am-parser.y" /* yacc.c:339  */
 
 
 #include "am-scanner.h"
@@ -84,7 +84,7 @@
 /* Token location is found directly from token value, there is no need to
  * maintain a separate location variable */
 #define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))
-#line 115 "../../../plugins/am-project/am-parser.y" /* yacc.c:339  */
+#line 115 "am-parser.y" /* yacc.c:339  */
 
 
 //amp_am_yydebug = 1;
@@ -138,7 +138,7 @@ amp_am_automake_variable (AnjutaToken *token)
 }
 
 
-#line 142 "../../../plugins/am-project/am-parser.c" /* yacc.c:339  */
+#line 142 "am-parser.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -158,8 +158,8 @@ amp_am_automake_variable (AnjutaToken *token)
 
 /* In a future release of Bison, this section will be replaced
    by #include "am-parser.h".  */
-#ifndef YY_AMP_AM_YY_PLUGINS_AM_PROJECT_AM_PARSER_H_INCLUDED
-# define YY_AMP_AM_YY_PLUGINS_AM_PROJECT_AM_PARSER_H_INCLUDED
+#ifndef YY_AMP_AM_YY_AM_PARSER_H_INCLUDED
+# define YY_AMP_AM_YY_AM_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -326,11 +326,11 @@ int amp_am_yypush_parse (amp_am_yypstate *ps, int pushed_char, YYSTYPE const *pu
 amp_am_yypstate * amp_am_yypstate_new (void);
 void amp_am_yypstate_delete (amp_am_yypstate *ps);
 
-#endif /* !YY_AMP_AM_YY_PLUGINS_AM_PROJECT_AM_PARSER_H_INCLUDED  */
+#endif /* !YY_AMP_AM_YY_AM_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 334 "../../../plugins/am-project/am-parser.c" /* yacc.c:358  */
+#line 334 "am-parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -351,13 +351,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -369,7 +369,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -421,7 +421,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -567,7 +567,7 @@ union yyalloc
 #define YYMAXUTOK   314
 
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex, without out-of-bounds checking.  */
@@ -1192,7 +1192,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule, AmpAmScanner* scanner)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1418,6 +1418,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1542,13 +1543,16 @@ yypstate_new (void)
 void
 yypstate_delete (yypstate *yyps)
 {
+  if (yyps)
+    {
 #ifndef yyoverflow
-  /* If the stack was reallocated but the parse did not complete, then the
-     stack still needs to be freed.  */
-  if (!yyps->yynew && yyps->yyss != yyps->yyssa)
-    YYSTACK_FREE (yyps->yyss);
+      /* If the stack was reallocated but the parse did not complete, then the
+         stack still needs to be freed.  */
+      if (!yyps->yynew && yyps->yyss != yyps->yyssa)
+        YYSTACK_FREE (yyps->yyss);
 #endif
-  free (yyps);
+      free (yyps);
+    }
 }
 
 #define amp_am_yynerrs yyps->amp_am_yynerrs
@@ -1705,7 +1709,7 @@ YYLTYPE yylloc = yyloc_default;
       yylsp = yyls + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
@@ -1823,13 +1827,14 @@ yyreduce:
      GCC warning that YYVAL may be used uninitialized.  */
   yyval = yyvsp[1-yylen];
 
-  /* Default location.  */
+  /* Default location. */
   YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
+  yyerror_range[1] = yyloc;
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 11:
-#line 188 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 188 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (amp_am_automake_variable ((yyvsp[-3])), NULL);
 		if ((yyvsp[-4]) != NULL) anjuta_token_set_type ((yyvsp[-4]), ANJUTA_TOKEN_START);
@@ -1839,11 +1844,11 @@ yyreduce:
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 		amp_am_scanner_set_am_variable (scanner, (yyval));
 	}
-#line 1843 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1848 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 12:
-#line 198 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 198 "am-parser.y" /* yacc.c:1651  */
     {
 		AnjutaToken *list;
 		list = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
@@ -1853,22 +1858,22 @@ yyreduce:
 		anjuta_token_merge ((yyval), list);
 		amp_am_scanner_set_am_variable (scanner, (yyval));
 	}
-#line 1857 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1862 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 13:
-#line 210 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 210 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[-1]));
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 		amp_am_scanner_include (scanner, (yyval));
 	}
-#line 1868 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1873 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 14:
-#line 218 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 218 "am-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
         anjuta_token_merge_own_children ((yyvsp[-2]));
@@ -1877,11 +1882,11 @@ yyreduce:
         anjuta_token_merge ((yyval), (yyvsp[0]));
         amp_am_scanner_update_variable (scanner, (yyval));
 	}
-#line 1881 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1886 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 15:
-#line 226 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 226 "am-parser.y" /* yacc.c:1651  */
     {
 		AnjutaToken *list;
 		list = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
@@ -1893,83 +1898,83 @@ yyreduce:
 		anjuta_token_merge ((yyval), list);
 		amp_am_scanner_update_variable (scanner, (yyval));
 	}
-#line 1897 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1902 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 24:
-#line 263 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 263 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_set_type ((yyvsp[0]), ANJUTA_TOKEN_EOL);
 		(yyval) = NULL;
 	}
-#line 1906 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1911 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 25:
-#line 267 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 267 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = NULL;
 	}
-#line 1914 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1919 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 26:
-#line 270 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 270 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_set_type ((yyvsp[0]), ANJUTA_TOKEN_COMMENT);
 		(yyval) = NULL;
 	}
-#line 1923 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1928 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 32:
-#line 293 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 293 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_merge_previous ((yyvsp[-1]), (yyvsp[-2]));
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 1932 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1937 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 33:
-#line 300 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 300 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 1941 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1946 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 34:
-#line 304 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 304 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[-1]));
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[0]));
 	}
-#line 1950 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1955 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 35:
-#line 308 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 308 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[-1]));
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[0]));
 	}
-#line 1959 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1964 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 36:
-#line 315 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 315 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
 		if ((yyvsp[0]) != NULL) anjuta_token_set_type ((yyvsp[0]), ANJUTA_TOKEN_START);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 1969 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1974 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 37:
-#line 320 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 320 "am-parser.y" /* yacc.c:1651  */
     {
 		if ((yyvsp[-2]) != NULL) anjuta_token_set_type ((yyvsp[-2]), ANJUTA_TOKEN_START);
 		if ((yyvsp[0]) != NULL) anjuta_token_set_type ((yyvsp[0]), ANJUTA_TOKEN_LAST);
@@ -1977,357 +1982,357 @@ yyreduce:
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 		(yyval) = (yyvsp[-1]);
 	}
-#line 1981 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1986 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 38:
-#line 329 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 329 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 1990 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 1995 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 39:
-#line 333 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 333 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_set_type ((yyvsp[-1]), ANJUTA_TOKEN_NEXT);
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[-1]));
 		anjuta_token_merge ((yyvsp[-2]), (yyvsp[0]));
 	}
-#line 2000 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2005 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 42:
-#line 351 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 351 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = NULL;
 	}
-#line 2008 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2013 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 44:
-#line 358 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 358 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2017 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2022 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 45:
-#line 366 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 366 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2025 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2030 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 46:
-#line 375 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 375 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2034 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2039 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 47:
-#line 379 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 379 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2043 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2048 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 48:
-#line 383 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 383 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2051 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2056 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 49:
-#line 386 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 386 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2059 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2064 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 50:
-#line 392 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 392 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2068 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2073 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 51:
-#line 396 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 396 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2077 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2082 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 52:
-#line 400 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 400 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2086 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2091 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 53:
-#line 404 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 404 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2094 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2099 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 54:
-#line 407 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 407 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2102 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2107 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 55:
-#line 410 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 410 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2110 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2115 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 56:
-#line 413 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 413 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2118 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2123 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 57:
-#line 416 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 416 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2126 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2131 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 58:
-#line 419 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 419 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2134 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2139 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 59:
-#line 422 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 422 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2142 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2147 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 60:
-#line 425 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 425 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2150 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2155 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 61:
-#line 428 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 428 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2158 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2163 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 62:
-#line 431 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 431 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2166 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2171 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 63:
-#line 437 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 437 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2175 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2180 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 64:
-#line 441 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 441 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2184 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2189 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 65:
-#line 445 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 445 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2193 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2198 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 66:
-#line 449 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 449 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2202 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2207 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 67:
-#line 453 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 453 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2211 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2216 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 68:
-#line 457 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 457 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2220 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2225 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 69:
-#line 461 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 461 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2228 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2233 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 70:
-#line 464 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 464 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2236 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2241 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 71:
-#line 467 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 467 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2244 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2249 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 72:
-#line 470 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 470 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2252 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2257 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 73:
-#line 473 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 473 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2260 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2265 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 74:
-#line 479 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 479 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2269 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2274 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 75:
-#line 483 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 483 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2278 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2283 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 76:
-#line 487 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 487 "am-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
 		anjuta_token_merge ((yyval), (yyvsp[0]));
 	}
-#line 2287 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2292 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 77:
-#line 491 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 491 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2295 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2300 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 78:
-#line 494 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 494 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2303 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2308 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 79:
-#line 497 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 497 "am-parser.y" /* yacc.c:1651  */
     {
 		anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 2311 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2316 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 87:
-#line 516 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 516 "am-parser.y" /* yacc.c:1651  */
     {
 		amp_am_scanner_parse_variable (scanner, (yyval));
 	}
-#line 2319 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2324 "am-parser.c" /* yacc.c:1651  */
     break;
 
   case 88:
-#line 522 "../../../plugins/am-project/am-parser.y" /* yacc.c:1646  */
+#line 522 "am-parser.y" /* yacc.c:1651  */
     {
 		amp_am_scanner_parse_ac_variable (scanner, (yyval));
 	}
-#line 2327 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2332 "am-parser.c" /* yacc.c:1651  */
     break;
 
 
-#line 2331 "../../../plugins/am-project/am-parser.c" /* yacc.c:1646  */
+#line 2336 "am-parser.c" /* yacc.c:1651  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2450,7 +2455,6 @@ yyerrorlab:
   if (/*CONSTCOND*/ 0)
      goto yyerrorlab;
 
-  yyerror_range[1] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -2565,5 +2569,5 @@ yypushreturn:
 #endif
   return yyresult;
 }
-#line 662 "../../../plugins/am-project/am-parser.y" /* yacc.c:1906  */
+#line 662 "am-parser.y" /* yacc.c:1910  */
 
