@@ -21,10 +21,19 @@
 #include "plugin.h"
 
 void
-cpp_indentation (IAnjutaEditor *editor,
-                 IAnjutaIterable *insert_pos,
-                 gchar ch,
-                 IndentCPlugin *plugin);
+cpp_java_indentation_char_added (IAnjutaEditor *editor,
+                                 IAnjutaIterable *insert_pos,
+                                 gchar ch,
+                                 IndentCPlugin *plugin);
+
+void
+cpp_java_indentation_changed (IAnjutaEditor *editor,
+                              IAnjutaIterable *position,
+                              gboolean added,
+                              gint length,
+                              gint lines,
+                              const gchar *text,
+                              IndentCPlugin* plugin);
 
 void
 cpp_auto_indentation (IAnjutaEditor *editor,
@@ -32,8 +41,3 @@ cpp_auto_indentation (IAnjutaEditor *editor,
                       IAnjutaIterable *start,
                       IAnjutaIterable *end);
 
-void
-java_indentation (IAnjutaEditor *editor,
-                  IAnjutaIterable *insert_pos,
-                  gchar ch,
-                  IndentCPlugin *plugin);
