@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -71,7 +71,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 19 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:339  */
+#line 19 "mk-parser.y" /* yacc.c:339  */
 
 
 #include "mk-scanner.h"
@@ -85,7 +85,7 @@
  * maintain a separate location variable */
 #define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))
 
-#line 89 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:339  */
+#line 89 "mk-parser.y" /* yacc.c:339  */
 
 
 //mkp_yydebug = 1;
@@ -168,7 +168,7 @@ mkp_special_target (AnjutaToken *list)
 }
 
 
-#line 172 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:339  */
+#line 172 "mk-parser.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -188,8 +188,8 @@ mkp_special_target (AnjutaToken *list)
 
 /* In a future release of Bison, this section will be replaced
    by #include "mk-parser.h".  */
-#ifndef YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
-# define YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
+#ifndef YY_MKP_YY_MK_PARSER_H_INCLUDED
+# define YY_MKP_YY_MK_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -310,11 +310,11 @@ int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_v
 mkp_yypstate * mkp_yypstate_new (void);
 void mkp_yypstate_delete (mkp_yypstate *ps);
 
-#endif /* !YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED  */
+#endif /* !YY_MKP_YY_MK_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 318 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:358  */
+#line 318 "mk-parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -335,13 +335,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -353,7 +353,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -405,7 +405,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -551,7 +551,7 @@ union yyalloc
 #define YYMAXUTOK   291
 
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex, without out-of-bounds checking.  */
@@ -1080,7 +1080,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule, void* scanner)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1306,6 +1306,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1430,13 +1431,16 @@ yypstate_new (void)
 void
 yypstate_delete (yypstate *yyps)
 {
+  if (yyps)
+    {
 #ifndef yyoverflow
-  /* If the stack was reallocated but the parse did not complete, then the
-     stack still needs to be freed.  */
-  if (!yyps->yynew && yyps->yyss != yyps->yyssa)
-    YYSTACK_FREE (yyps->yyss);
+      /* If the stack was reallocated but the parse did not complete, then the
+         stack still needs to be freed.  */
+      if (!yyps->yynew && yyps->yyss != yyps->yyssa)
+        YYSTACK_FREE (yyps->yyss);
 #endif
-  free (yyps);
+      free (yyps);
+    }
 }
 
 #define mkp_yynerrs yyps->mkp_yynerrs
@@ -1593,7 +1597,7 @@ YYLTYPE yylloc = yyloc_default;
       yylsp = yyls + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
@@ -1711,22 +1715,23 @@ yyreduce:
      GCC warning that YYVAL may be used uninitialized.  */
   yyval = yyvsp[1-yylen];
 
-  /* Default location.  */
+  /* Default location. */
   YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
+  yyerror_range[1] = yyloc;
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 8:
-#line 184 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 184 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge_children ((yyvsp[-1]), (yyvsp[0]));
         mkp_scanner_add_rule (scanner, (yyvsp[-1]));
     }
-#line 1726 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1731 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 9:
-#line 191 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 191 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
         anjuta_token_merge_own_children ((yyvsp[-2]));
@@ -1735,11 +1740,11 @@ yyreduce:
         anjuta_token_merge ((yyval), (yyvsp[0]));
         mkp_scanner_update_variable (scanner, (yyval));
     }
-#line 1739 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1744 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 10:
-#line 199 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 199 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
         anjuta_token_merge_own_children ((yyvsp[-1]));
@@ -1747,29 +1752,29 @@ yyreduce:
         anjuta_token_merge ((yyval), (yyvsp[0]));
         mkp_scanner_update_variable (scanner, (yyval));
     }
-#line 1751 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1756 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 11:
-#line 209 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 209 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 1759 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1764 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 12:
-#line 212 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 212 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[-2]));
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[-1]));
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[0]));
     }
-#line 1769 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1774 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 13:
-#line 220 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 220 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_RULE, NULL);
         anjuta_token_merge ((yyval), (yyvsp[-2]));
@@ -1788,61 +1793,61 @@ yyreduce:
         anjuta_token_merge ((yyval), (yyvsp[-1]));
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1792 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1797 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 14:
-#line 241 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 241 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMANDS, NULL);
     }
-#line 1800 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1805 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 15:
-#line 244 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 244 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[-2]));
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[-1]));
         anjuta_token_merge ((yyvsp[-3]), (yyvsp[0]));
     }
-#line 1810 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1815 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 19:
-#line 262 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 262 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = NULL;
     }
-#line 1818 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1823 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 20:
-#line 265 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 265 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = NULL;
     }
-#line 1826 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1831 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 24:
-#line 280 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 280 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
     }
-#line 1834 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1839 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 25:
-#line 283 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 283 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
     }
-#line 1842 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1847 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 26:
-#line 286 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 286 "mk-parser.y" /* yacc.c:1651  */
     {
         if ((yyvsp[-2])) anjuta_token_set_type ((yyvsp[-2]), ANJUTA_TOKEN_START);
         if ((yyvsp[0])) anjuta_token_set_type ((yyvsp[0]), ANJUTA_TOKEN_LAST);
@@ -1850,210 +1855,210 @@ yyreduce:
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
         (yyval) = (yyvsp[-1]);
     }
-#line 1854 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1859 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 27:
-#line 296 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 296 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1863 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1868 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 28:
-#line 300 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 300 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_set_type ((yyvsp[-1]), ANJUTA_TOKEN_NEXT);
         anjuta_token_merge ((yyvsp[-2]), (yyvsp[-1]));
         anjuta_token_merge ((yyvsp[-2]), (yyvsp[0]));
 	}
-#line 1873 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1878 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 29:
-#line 308 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 308 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_merge_previous ((yyvsp[-1]), (yyvsp[-2]));
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1882 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1887 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 30:
-#line 315 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 315 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1891 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1896 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 31:
-#line 319 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 319 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-2]), (yyvsp[-1]));
         anjuta_token_merge ((yyvsp[-2]), (yyvsp[0]));
     }
-#line 1900 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1905 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 32:
-#line 326 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 326 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMAND, NULL);
     }
-#line 1908 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1913 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 33:
-#line 329 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 329 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 1916 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1921 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 34:
-#line 338 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 338 "mk-parser.y" /* yacc.c:1651  */
     {
 		(yyval) = NULL;
 	}
-#line 1924 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1929 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 36:
-#line 345 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 345 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1933 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1938 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 37:
-#line 349 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 349 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
 	}
-#line 1941 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1946 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 39:
-#line 356 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 356 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1950 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1955 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 40:
-#line 360 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 360 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 1958 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1963 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 42:
-#line 367 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 367 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1967 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1972 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 43:
-#line 371 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 371 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 1976 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1981 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 44:
-#line 375 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 375 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 1984 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1989 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 45:
-#line 378 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 378 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 1992 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 1997 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 47:
-#line 388 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 388 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (mkp_special_prerequisite ((yyvsp[0])), NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 2001 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2006 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 48:
-#line 392 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 392 "mk-parser.y" /* yacc.c:1651  */
     {
         anjuta_token_merge ((yyvsp[-1]), (yyvsp[0]));
     }
-#line 2009 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2014 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 50:
-#line 399 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 399 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_EQUAL, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 2018 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2023 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 51:
-#line 403 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 403 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_IMMEDIATE_EQUAL, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 2027 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2032 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 52:
-#line 407 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 407 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_CONDITIONAL_EQUAL, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 2036 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2041 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 53:
-#line 411 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 411 "mk-parser.y" /* yacc.c:1651  */
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_APPEND, NULL);
         anjuta_token_merge ((yyval), (yyvsp[0]));
     }
-#line 2045 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2050 "mk-parser.c" /* yacc.c:1651  */
     break;
 
   case 72:
-#line 455 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1646  */
+#line 455 "mk-parser.y" /* yacc.c:1651  */
     {
         mkp_scanner_parse_variable (scanner, (yyval));
     }
-#line 2053 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2058 "mk-parser.c" /* yacc.c:1651  */
     break;
 
 
-#line 2057 "../../../plugins/mk-project/mk-parser.c" /* yacc.c:1646  */
+#line 2062 "mk-parser.c" /* yacc.c:1651  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2176,7 +2181,6 @@ yyerrorlab:
   if (/*CONSTCOND*/ 0)
      goto yyerrorlab;
 
-  yyerror_range[1] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -2291,5 +2295,5 @@ yypushreturn:
 #endif
   return yyresult;
 }
-#line 533 "../../../plugins/mk-project/mk-parser.y" /* yacc.c:1906  */
+#line 533 "mk-parser.y" /* yacc.c:1910  */
 
