@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.1.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
-# define YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED
+#ifndef YY_MKP_YY_MK_PARSER_H_INCLUDED
+# define YY_MKP_YY_MK_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -152,4 +152,4 @@ int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_v
 mkp_yypstate * mkp_yypstate_new (void);
 void mkp_yypstate_delete (mkp_yypstate *ps);
 
-#endif /* !YY_MKP_YY_PLUGINS_MK_PROJECT_MK_PARSER_H_INCLUDED  */
+#endif /* !YY_MKP_YY_MK_PARSER_H_INCLUDED  */
