@@ -1,8 +1,8 @@
 [+ autogen5 template +]
 #!/usr/bin/env python
-# [+INVOKE EMACS-MODELINE MODE="Python; coding: utf-8" +]
 [+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
 [+INCLUDE (string-append "indent.tpl") \+]
+# [+INVOKE EMACS-MODELINE MODE="Python; coding: utf-8" +]
 [+INVOKE START-INDENT\+]
 #
 # main.py
@@ -31,12 +31,12 @@ class GUI:
 [+ELSE+]
 		window = Gtk.Window()
 		window.set_title ("Hello World")
-		window.connect_after('destroy', self.destroy)
+		window.connect_after('destroy', self.on_window_destroy)
 [+ENDIF+]
 
 		window.show_all()
 
-	def destroy(window, self):
+	def on_window_destroy(self, window):
 		Gtk.main_quit()
 
 def main():
