@@ -126,7 +126,7 @@ typedef struct sTokenInfo {
 	vString *		string;
 	vString *		scope;
 	unsigned long 	lineNumber;
-	fpos_t 			filePosition;
+	long   			filePosition;
 	int				nestLevel;
 	boolean			ignoreTag;
 	boolean			isClass;
